@@ -5,16 +5,16 @@ def install(package):
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
 
 
-__Packagelocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("pytorchcv-0.0.55-py2.py3-none-any.whl")))
-PackagePath = os.path.join(__Packagelocation__, "deepfake_detection","pytorchcv-0.0.55-py2.py3-none-any.whl")
+# __Packagelocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(".\\pytorchcv-0.0.55-py2.py3-none-any.whl")))
+# PackagePath = os.path.join(__Packagelocation__, "deepfake_detection","pytorchcv-0.0.55-py2.py3-none-any.whl")
 
-__Blazefacelocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("blazeface.pth")))
-BlazefacePath = os.path.join(__Blazefacelocation__, "deepfake_detection","blazeface.pth")
+# __Blazefacelocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("blazeface.pth")))
+# BlazefacePath = os.path.join(__Blazefacelocation__, "deepfake_detection","blazeface.pth")
 
-__Anchorslocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("anchors.npy")))
-AnchorsPath = os.path.join(__Anchorslocation__, "deepfake_detection","anchors.npy")
+# __Anchorslocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("anchors.npy")))
+# AnchorsPath = os.path.join(__Anchorslocation__, "deepfake_detection","anchors.npy")
 
-install(PackagePath)
+install('pytorchcv-0.0.55-py2.py3-none-any.whl')
 install("pytube")
 install("moviepy")
 install("youtube-dl")
@@ -1009,8 +1009,8 @@ def overlap_similarity(box, other_boxes):
 
 #######################################################################
 facedet = BlazeFace().to(device)
-facedet.load_weights(BlazefacePath)
-facedet.load_anchors(AnchorsPath)
+facedet.load_weights('blazeface.pth')
+facedet.load_anchors('anchors.npy')
 _ = facedet.train(False)
 
 
